import * as fs from "fs";
import * as path from "path";
import mkdirp from "mkdirp";
/**
 * Command line utils functions.
 */
export class CommandUtils {
    /**
     * Creates directories recursively.
     */
    static createDirectories(directory) {
        return mkdirp(directory);
    }
    /**
     * Creates a file with the given content in the given path.
     */
    static async createFile(filePath, content, override = true) {
        await CommandUtils.createDirectories(path.dirname(filePath));
        return new Promise((ok, fail) => {
            if (override === false && fs.existsSync(filePath))
                return ok();
            fs.writeFile(filePath, content, err => err ? fail(err) : ok());
        });
    }
    /**
     * Reads everything from a given file and returns its content as a string.
     */
    static async readFile(filePath) {
        return new Promise((ok, fail) => {
            fs.readFile(filePath, (err, data) => err ? fail(err) : ok(data.toString()));
        });
    }
    static async fileExists(filePath) {
        return fs.existsSync(filePath);
    }
}

//# sourceMappingURL=CommandUtils.js.map
